@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1996-2012 by the citadel.org team
+ * Copyright (c) 1996-2013 by the citadel.org team
  *
  * This program is open source software.  You can redistribute it and/or
  * modify it under the terms of the GNU General Public License version 3.
@@ -14,9 +14,6 @@
 #include "webserver.h"
 
 #include "modules_init.h"
-#ifndef HAVE_SNPRINTF
-int vsnprintf(char *buf, size_t max, const char *fmt, va_list argp);
-#endif
 
 extern int msock;				/* master listening socket */
 extern char static_icon_dir[PATH_MAX];          /* where should we find our mime icons */
